==> haskell-lattices-2.2.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lattices.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lattices
version:              2.2.1
visibility:           public
id:                   lattices-2.2.1-K4Hf8OqycXk3siXMkEEkmg
key:                  lattices-2.2.1-K4Hf8OqycXk3siXMkEEkmg
license:              BSD-3-Clause
copyright:
    (C) 2010-2015 Maximilian Bolingbroke, 2016-2019 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Maximilian Bolingbroke <batterseapower@hotmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             http://github.com/phadej/lattices/
synopsis:
    Fine-grained library for constructing and manipulating lattices

description:
    In mathematics, a lattice is a partially ordered set in which every two
    elements @x@ and @y@ have a unique supremum (also called a least upper bound, join, or @x /\\ y@)
    and a unique infimum (also called a greatest lower bound, meet, or @x \\/ y@).

    This package provide type-classes for different lattice types, as well
    as a class for the partial order.

category:             Math
abi:                  4a1ec16f5d8b6b55f21aed653ff702ce
exposed:              True
exposed-modules:
    Algebra.Heyting Algebra.Heyting.Free Algebra.Heyting.Free.Expr
    Algebra.Lattice Algebra.Lattice.Divisibility
    Algebra.Lattice.Dropped Algebra.Lattice.Free
    Algebra.Lattice.Free.Final Algebra.Lattice.Levitated
    Algebra.Lattice.Lexicographic Algebra.Lattice.Lifted
    Algebra.Lattice.M2 Algebra.Lattice.M3 Algebra.Lattice.N5
    Algebra.Lattice.Op Algebra.Lattice.Ordered Algebra.Lattice.Unicode
    Algebra.Lattice.Wide Algebra.Lattice.ZeroHalfOne Algebra.PartialOrd
    Algebra.PartialOrd.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lattices
hs-libraries:         HSlattices-2.2.1-K4Hf8OqycXk3siXMkEEkmg
depends:
    QuickCheck-2.14.3-JT8ioqllyin7h2duLhwDbF base-4.17.2.1
    containers-0.6.7 deepseq-1.4.8.0
    foldable1-classes-compat-0.1-B7gyeo5pUdsKMqt4HyH2XT
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    integer-logarithms-1.0.4-B4xdIn5EqPvMTifdxHklv
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    universe-base-1.1.4-L106gP9KkpW46D6jQP4DWt
    universe-reverse-instances-1.1.2-6jhDwyfShMF0BNE4YmnVe
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i

haddock-interfaces:   /usr/share/doc/haskell-lattices/html/lattices.haddock
haddock-html:         /usr/share/doc/haskell-lattices/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lattices-2.2.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lattices.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lattices
version:              2.2.1
visibility:           public
id:                   lattices-2.2.1-B5QksWKHcqB5D6kNpFiKip
key:                  lattices-2.2.1-B5QksWKHcqB5D6kNpFiKip
license:              BSD-3-Clause
copyright:
    (C) 2010-2015 Maximilian Bolingbroke, 2016-2019 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Maximilian Bolingbroke <batterseapower@hotmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             http://github.com/phadej/lattices/
synopsis:
    Fine-grained library for constructing and manipulating lattices

description:
    In mathematics, a lattice is a partially ordered set in which every two
    elements @x@ and @y@ have a unique supremum (also called a least upper bound, join, or @x /\\ y@)
    and a unique infimum (also called a greatest lower bound, meet, or @x \\/ y@).

    This package provide type-classes for different lattice types, as well
    as a class for the partial order.

category:             Math
abi:                  83bd44cfc1d034ceb1e06986960fba97
exposed:              True
exposed-modules:
    Algebra.Heyting Algebra.Heyting.Free Algebra.Heyting.Free.Expr
    Algebra.Lattice Algebra.Lattice.Divisibility
    Algebra.Lattice.Dropped Algebra.Lattice.Free
    Algebra.Lattice.Free.Final Algebra.Lattice.Levitated
    Algebra.Lattice.Lexicographic Algebra.Lattice.Lifted
    Algebra.Lattice.M2 Algebra.Lattice.M3 Algebra.Lattice.N5
    Algebra.Lattice.Op Algebra.Lattice.Ordered Algebra.Lattice.Unicode
    Algebra.Lattice.Wide Algebra.Lattice.ZeroHalfOne Algebra.PartialOrd
    Algebra.PartialOrd.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lattices
hs-libraries:         HSlattices-2.2.1-B5QksWKHcqB5D6kNpFiKip
depends:
    QuickCheck-2.14.3-JT8ioqllyin7h2duLhwDbF base-4.17.2.1
    containers-0.6.7 deepseq-1.4.8.0
    foldable1-classes-compat-0.1-3zuLVL30tsR758nicYVNNR
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    integer-logarithms-1.0.4-B4xdIn5EqPvMTifdxHklv
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    universe-base-1.1.4-L106gP9KkpW46D6jQP4DWt
    universe-reverse-instances-1.1.2-6jhDwyfShMF0BNE4YmnVe
    unordered-containers-0.2.20-7moq3V15ycBgVs1tpEAw

haddock-interfaces:   /usr/share/doc/haskell-lattices/html/lattices.haddock
haddock-html:         /usr/share/doc/haskell-lattices/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
